TransferSocket class abstract

Implementers

Constructors

TransferSocket()

Properties

hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() FutureOr<void>
inherited
connect({Duration? timeout}) Future<void>
listen({void onData(Uint8List event)?, void onDone()?}) StreamSubscription<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(List<int> data) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited